﻿/*
  This file is part of Sanmill.
  Copyright (C) 2019-2021 The Sanmill developers (see AUTHORS file)

  Sanmill is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Sanmill is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMEWINDOW_H
#define GAMEWINDOW_H

#include <vector>

#include <QtWidgets/QMainWindow>
#include <QTextStream>
#include <QStringListModel>
#include <QFile>
#include <QTimer>

#include "config.h"

#include "ui_gamewindow.h"

#include "server.h"
#include "client.h"

using namespace std;

class GameScene;
class Game;

class MillGameWindow : public QMainWindow
{
    Q_OBJECT

public:
    MillGameWindow(QWidget *parent = nullptr);
    ~MillGameWindow() override;

protected:
    bool eventFilter(QObject *watched, QEvent *event) override;
    void closeEvent(QCloseEvent *event) override;
#ifdef MOBILE_APP_UI
    void mousePressEvent(QMouseEvent *mouseEvent) override;
    void mouseMoveEvent(QMouseEvent *mouseEvent) override;
    void mouseReleaseEvent(QMouseEvent *mouseEvent) override;
#endif /* MOBILE_APP_UI */

private slots:
    void initialize();

#ifdef MOBILE_APP_UI
    void ctxMenu(const QPoint &pos);
#endif /* MOBILE_APP_UI */

    void actionRules_triggered();

    void ruleInfo();

    void onAutoRunTimeOut(QPrivateSignal signal);

    // The slot function for each action
    // Remove functions have been connected in UI manager or main window initialization function
    void on_actionNew_N_triggered();
    void on_actionOpen_O_triggered();
    void on_actionSave_S_triggered();
    void on_actionSaveAs_A_triggered();
#if 0
    void on_actionExit_X_triggered();
#endif
    void on_actionEdit_E_toggled(bool arg1);
#if 0
    void on_actionFlip_F_triggered();
    void on_actionMirror_M_triggered();
    void on_actionTurnRight_R_triggered();
    void on_actionTurnLeftt_L_triggered();
#endif
    void on_actionInvert_I_toggled(bool arg1);
    void on_actionRowChange();
    void on_actionAutoRun_A_toggled(bool arg1);
    //void on_actionResign_G_triggered();
    void on_actionLimited_T_triggered();
    void on_actionLocal_L_triggered();
    void on_actionEngineFight_E_triggered();
    void on_actionInternet_I_triggered();
    void on_actionEngine_E_triggered();
#if 0
    void on_actionEngine1_R_toggled(bool arg1);
    void on_actionEngine2_T_toggled(bool arg1);
    void on_actionSetting_O_triggered();
    void on_actionToolBar_T_toggled(bool arg1);
    void on_actionDockBar_D_toggled(bool arg1);
    void on_actionSound_S_toggled(bool arg1);
    void on_actionAnimation_A_toggled(bool arg1);
    void on_actionAutoRestart_A_triggered();
#endif
    void on_actionViewHelp_V_triggered();
    void on_actionWeb_W_triggered();
    void on_actionAbout_A_triggered();

protected:
    void saveBook(const QString &path);

private:
    Ui::MillGameWindowClass ui {};
    GameScene *scene {nullptr};
    Game *game {nullptr};
    vector<QAction *> ruleActionList;
    int ruleNo {-1};
    QFile file;
    QTimer autoRunTimer;

#ifdef MOBILE_APP_UI
    bool m_move {false};
    QPoint m_startPoint;
    QPoint m_windowPoint;
#endif
};

#endif // GAMEWINDOW_H
